.. _concepts:

********
Concepts
********

There are a few concepts behind the implementation of Dune-MMesh that we shall describe in more detail.
The concepts can be split into three main parts: :ref:`wrapper`, :ref:`interface` and :ref:`moving`.

.. toctree::
  :maxdepth: 1
  :hidden:

  concepts/wrapper
  concepts/interface
  concepts/moving
